@@ -35,5 +35,9 @@ class SDK:
     def payment(self):
         return self._sdk.payment()
 
+    def refund(self):
+        return self._sdk.refund()
+
     def which(self):
-        return self.processor 
+        return self.processor
+
