@@ -58,7 +58,7 @@ class Payment:
         r = requests.get(self.url + '/payments/{}'.format(payment_id), headers=self.headers)
         return ok(r.json())
 
-    def search(self,filters:dict) -> dict:
+    def search(self, filters: dict) -> dict:
         # El filter puede ser:
         # offset
         # pageSize
@@ -67,9 +67,5 @@ class Payment:
         # dateFrom
         # dateTo
         # site
-        r = requests.get(self.url + '/payments',params=filters, headers=self.headers)
+        r = requests.get(self.url + '/payments', params=filters, headers=self.headers)
         return r.json()
-
-    def refund(self,payment_id:str):
-        r = requests.post(self.url + f'/payments/{payment_id}/refunds', headers=self.headers)
-        return r.json()
\ No newline at end of file
